localfileeditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# localfileeditor

class `camelot.view.controls.editors.localfileeditor.` `LocalFileEditor`(parent=None, field_name='local_file', directory=False, save_as=False, file_filter='All files (*)', **kwargs)

  Widget for browsing local files and directories

  `setup_widget`()

    Called inside init, overwrite this method for custom file edit widgets

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus